package summarizer;

import java.util.HashSet;
import java.util.Set;

public class Edge {

	private Node source;
	private Node target;
	private Set<String> labels;
	private int weight;

	public Edge(Node source, Node target) {
		super();
		this.source = source;
		this.target = target;
		this.labels = new HashSet<String>();
	}

	public Edge(Node source, Node target, String label) {
		this(source, target);
		this.labels.add(label);
	}

	public Edge(Node source, Node target, int weigth) {
		super();
		this.source = source;
		this.target = target;
		this.weight = weigth;
		this.labels = new HashSet<String>();
	}

	public Node getSource() {
		return source;
	}

	public void setSource(Node source) {
		this.source = source;
	}

	public Node getTarget() {
		return target;
	}

	public void setTarget(Node target) {
		this.target = target;
	}

	public int getWeigth() {
		return weight;
	}

	public void setWeigth(int weigth) {
		this.weight = weigth;
	}

	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result + ((source == null) ? 0 : source.hashCode());
		result = prime * result + ((target == null) ? 0 : target.hashCode());
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj) {
			return true;
		}
		if (obj == null) {
			return false;
		}
		if (getClass() != obj.getClass()) {
			return false;
		}
		Edge other = (Edge) obj;
		if (source == null) {
			if (other.source != null) {
				return false;
			}
		} else if (!source.equals(other.source)) {
			return false;
		}
		if (target == null) {
			if (other.target != null) {
				return false;
			}
		} else if (!target.equals(other.target)) {
			return false;
		}
		return true;
	}

	public String getLabel() {
		String label = "";
		for (String edgeLabel : labels) {
			label += edgeLabel + ", ";
		}
		if (label.length() >= 2) {
			label = label.substring(0, label.length() - 2);
		}
		return label;
	}

	public void addLabel(String label) {
		this.labels.add(label);
	}

	@Override
	public String toString() {
		String result = "";
		String a = "";
		String b = "";
		if (this.source != null) {
			a = this.source.toString();
		}
		if (this.target != null) {
			b = this.target.toString();
		}
		if (this.labels.size() == 0) {
			result = a + " -> " + b;
		} else {
			String label = "";
			for (String edgeLabel : labels) {
				label += edgeLabel + " - ";
			}
			if (label.length() >= 3) {
				label = label.substring(0, label.length() - 3);
			}
			result = "(" + a + ", " + label + ", " + b + ")";
		}
		return result;
	}

	public boolean isAutoEdge() {
		return this.source.equals(this.target);
	}

	public boolean isInverseOf(Object obj) {
		if (this == obj) {
			return true;
		}
		if (obj == null) {
			return false;
		}
		if (getClass() != obj.getClass()) {
			return false;
		}
		Edge other = (Edge) obj;
		if (source == null) {
			if (other.source != null) {
				return false;
			}
		} else if (!source.equals(other.target)) {
			return false;
		}
		if (target == null) {
			if (other.target != null) {
				return false;
			}
		} else if (!target.equals(other.source)) {
			return false;
		}
		return true;
	}

	public Node getOtherPoint(Node node) {
		Node point = null;
		if (this.source.equals(node)) {
			point = this.target;
		} else if (this.target.equals(node)) {
			point = this.source;
		}
		return point;
	}

	public Edge getCopy() {
		Edge copy = new Edge(this.source.getCopy(), this.target.getCopy());
		for (String label : this.labels) {
			copy.addLabel(label);
		}
		copy.setWeigth(this.weight);
		return copy;
	}

	public void setOtherPointSource(Node node1, Node node2) {
		if (node1.equals(this.source)) {
			this.source = node2;
		} else if (node1.equals(this.target)) {
			this.target = node2;
		}
	}

	public boolean isFullRelevant() {
		return (this.getSource() != null) && (this.getTarget() != null)
				&& this.getSource().isRelevant()
				&& this.getTarget().isRelevant();
	}

	public static void main(String[] args) {
		Node a = new Node(1);
		Node b = new Node(2);
		Edge e1 = new Edge(a, a);
		Edge e2 = new Edge(a, a);
		Edge e3 = new Edge(a, b);
		Set<Edge> edges1 = new HashSet<Edge>();
		edges1.add(e3);
		edges1.add(e2);
		Set<Edge> edges2 = new HashSet<Edge>();
		edges2.add(e3);
		edges2.add(e1);
		System.out.println(edges1.hashCode());
		System.out.println(edges2.hashCode());
	}
}
