package summarizer;

import java.util.HashSet;
import java.util.Set;

public class Node implements Comparable<Node> {

	private int id;
	private String label;
	private boolean relevant;
	private double relevance;
	private Graph subgraph;
	private Set<Node> sourceConnectionPoints;
	private Set<Node> targetConnectionPoints;

	public Node(int id, String label) {
		this(id);
		this.label = label;
	}

	public Node(int id) {
		this.id = id;
		this.label = "";
		this.sourceConnectionPoints = new HashSet<Node>();
		this.targetConnectionPoints = new HashSet<Node>();
	}

	public double getRelevance() {
		return relevance;
	}

	public void setRelevance(double relevance) {
		this.relevance = relevance;
	}

	public int getId() {
		return id;
	}

	public void setId(int id) {
		this.id = id;
	}

	public String getLabel() {
		return label;
	}

	public void setLabel(String label) {
		this.label = label;
	}

	public boolean isRelevant() {
		return relevant;
	}

	public void setRelevant(boolean relevant) {
		this.relevant = relevant;
	}

	public Graph getSubgraph() {
		return subgraph;
	}

	public void setSubgraph(Graph subgraph) {
		this.subgraph = subgraph;
	}

	public boolean isSubgraph() {
		return (subgraph != null);
	}

	public Set<Node> getNodes() {
		if (this.subgraph != null) {
			return this.subgraph.getNodes();
		}
		return null;
	}

	public Set<Edge> getEdges() {
		if (this.subgraph != null) {
			return this.subgraph.getEdges();
		}
		return null;
	}

	public Set<Node> getSourceConnectionPoints() {
		return sourceConnectionPoints;
	}

	public void setSourceConnectionPoints(Set<Node> sourceConnectionPoints) {
		this.sourceConnectionPoints = sourceConnectionPoints;
	}

	public Set<Node> getTargetConnectionPoints() {
		return targetConnectionPoints;
	}

	public void setTargetConnectionPoints(Set<Node> targetConnectionPoints) {
		this.targetConnectionPoints = targetConnectionPoints;
	}

	public Node getCopy() {
		Node copy = new Node(this.id);
		copy.setLabel(this.label);
		copy.setRelevance(this.relevance);
		copy.setRelevant(this.relevant);
		if (this.subgraph != null) {
			copy.setSubgraph(this.subgraph.getCopy());
			copy.setSourceConnectionPoints(this.sourceConnectionPoints);
			copy.setTargetConnectionPoints(this.targetConnectionPoints);
		}
		return copy;
	}

	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result + id;
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj) {
			return true;
		}
		if (obj == null) {
			return false;
		}
		if (getClass() != obj.getClass()) {
			return false;
		}
		Node other = (Node) obj;
		if (id != other.id) {
			return false;
		}
		return true;
	}

	@Override
	public String toString() {
		String output = this.label;
		if (this.isSubgraph()) {
			output = this.getSubgraph().getNodes().toString();
		} /*
		 * else { output += " (ID=" + this.id + ")"; }
		 */
		return output;
	}

	public int compareTo(Node o) {
		int comparision = -1;
		if (o.getRelevance() == this.relevance) {
			comparision = 0;
		} else if (o.getRelevance() > this.relevance) {
			comparision = 1;
		}
		return comparision;
	}

}
