package summarizer;

import java.net.URI;
import java.util.Set;

import org.semanticweb.owl.apibinding.OWLManager;
import org.semanticweb.owl.model.OWLOntology;
import org.semanticweb.owl.model.OWLOntologyCreationException;
import org.semanticweb.owl.model.OWLOntologyManager;

public class O2GParser {

	private Ontology ontology;
	private Graph graph;

	public O2GParser(Graph graph) {
		this.graph = graph;
	}

	public O2GParser(Ontology ontology) {
		this.ontology = ontology;
	}

	public Graph parse(Ontology ontology) {
		Graph graph = new Graph();
		graph.setName(ontology.getName());
		int nodeIndex = 1;
		if (ontology != null) {
			Set<String> concepts = ontology.getConcepts();
			for (String concept : concepts) {
				Node node = new Node(nodeIndex, concept);
				graph.addNode(node);
				nodeIndex++;
			}
			Set<Triple> triples = ontology.getTriples();
			for (Triple triple : triples) {
				Edge edge = new Edge(graph.getNodeByLabel(triple
						.getSourceConcept()), graph.getNodeByLabel(triple
						.getTargetConcept()));
				edge.addLabel(triple.getName());
				graph.addEdge(edge);
			}
		}
		return graph;
	}

	public Ontology parse(Graph graph, String ontologyURIAddress,
			String physicalURIAddress) throws OWLOntologyCreationException {
		Ontology ontology = new Ontology(ontologyURIAddress, physicalURIAddress);
		return ontology;
	}

	public void parse() {
		this.graph = this.parse(this.ontology);
	}

	public Graph getGraph() {
		return graph;
	}

	public void setGraph(Graph graph) {
		this.graph = graph;
	}

	public Ontology getOntology() {
		return ontology;
	}

	public void setOntology(Ontology ontology) {
		this.ontology = ontology;
	}

	public static void main(String[] args) {
		try {
			OWLOntologyManager manager = OWLManager.createOWLOntologyManager();
			URI physicalURI = URI.create("file:///"
					+ "c:/cin/ultimo-periodo/tg/conference.owl");
			OWLOntology owl = manager.loadOntologyFromPhysicalURI(physicalURI);
			Ontology ont = new Ontology(owl);
			O2GParser o2g = new O2GParser(ont);
			o2g.parse();
		} catch (OWLOntologyCreationException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}
}
