package summarizer;

import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.OutputStreamWriter;
import java.io.UnsupportedEncodingException;
import java.net.URI;

import org.semanticweb.owl.apibinding.OWLManager;
import org.semanticweb.owl.model.OWLOntology;
import org.semanticweb.owl.model.OWLOntologyCreationException;
import org.semanticweb.owl.model.OWLOntologyManager;

public class XGMMLWriter {

	private static final String STRING_FORMAT = "UTF-8";
	public static final String XML_HEAD = "<?xml version=\"1.0\"?>";
	public static final String DOCTYPE = "<!DOCTYPE graph SYSTEM \"http://www.cs.rpi.edu/~puninj/XGMML/xgmml.dtd\">";
	public static final String LINE_BREAK = "\n";

	private String filename;
	private Graph graph;

	public XGMMLWriter(String filename, Graph graph) {
		super();
		this.filename = filename;
		this.graph = graph;
	}

	public boolean writeXGMML() {
		boolean success = true;
		FileOutputStream fos;
		OutputStreamWriter out;
		try {
			fos = new FileOutputStream(filename);
			out = new OutputStreamWriter(fos, STRING_FORMAT);
			out.write(XML_HEAD + LINE_BREAK);
			out.write(DOCTYPE + LINE_BREAK);
			out.write(LINE_BREAK);
			out.write(this.getGraphTag(graph.isDirected(), graph.getId(), graph
					.getName())
					+ LINE_BREAK);
			out.write(LINE_BREAK);
			for (Node node : graph.getNodes()) {
				out.write(this.getNodeTag(node.getId(), node.getLabel())
						+ LINE_BREAK);
				out.write(this.getNodeEndTag() + LINE_BREAK);
			}
			out.write(LINE_BREAK);
			for (Edge edge : graph.getEdges()) {
				out.write(this.getEdgeTag(edge.getSource().getId(), edge
						.getTarget().getId(), edge.getLabel())
						+ LINE_BREAK);
				out.write(this.getEdgeEndTag() + LINE_BREAK);
			}
			out.write(LINE_BREAK);
			out.write(this.getGraphEndTag());
			out.flush();
			out.close();
			fos.flush();
			fos.close();
		} catch (FileNotFoundException e) {
			success = false;
			e.printStackTrace();
		} catch (UnsupportedEncodingException e) {
			success = false;
			e.printStackTrace();
		} catch (IOException e) {
			success = false;
			e.printStackTrace();
		}
		return success;

	}

	private String getGraphTag(int directed, int id, String name) {
		String tag = "<graph directed=\"" + directed + "\" id=\"" + id
				+ "\" label=\"" + name + "\" >";
		return tag;
	}

	private String getGraphEndTag() {
		return "</graph>";
	}

	private String getNodeTag(int id, String label) {
		String tag = "<node id=\"" + id + "\" label=\"" + label + "\" >";
		return tag;
	}

	private String getNodeEndTag() {
		return "</node>";
	}

	private String getEdgeTag(int sourceID, int targetID, String name) {
		String tag = "<edge source=\"" + sourceID + "\" target=\"" + targetID
				+ "\" label=\"" + name + "\" >";
		return tag;
	}

	private String getEdgeEndTag() {
		return "</edge>";
	}

	public String getFilename() {
		return filename;
	}

	public void setFilename(String filename) {
		this.filename = filename;
	}

	public Graph getGraph() {
		return graph;
	}

	public void setGraph(Graph graph) {
		this.graph = graph;
	}

	public static void main(String[] args) {
		try {
			OWLOntologyManager manager = OWLManager.createOWLOntologyManager();
			// URI physicalURI = URI.create(
			// "http://www.co-ode.org/ontologies/pizza/2007/02/12/pizza.owl");
			// URI physicalURI =
			// URI.create("file:etc/ontologies/LO01-Education.owl");
			URI physicalURI = URI
					.create("file:///c:/workspace/eclipse/O2GParser/etc/ontologies/LO01-Education.owl");
			OWLOntology owl = manager.loadOntologyFromPhysicalURI(physicalURI);

			Ontology ont = new Ontology(owl);
			System.out.println(manager.getPhysicalURIForOntology(owl));

			O2GParser o2g = new O2GParser(ont);
			o2g.parse();
			XGMMLWriter xgmmlWriter = new XGMMLWriter(
					"C:\\workspace\\eclipse\\openjgraph\\etc\\test1.xgmml", o2g
							.getGraph());
			xgmmlWriter.writeXGMML();
		} catch (OWLOntologyCreationException e) {
			e.printStackTrace();
		}
	}

}
