package summarizer;

import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;

import javax.xml.parsers.SAXParser;
import javax.xml.parsers.SAXParserFactory;

import org.xml.sax.Attributes;
import org.xml.sax.SAXException;
import org.xml.sax.helpers.DefaultHandler;

public class XMLOntologyDataParser {

	private String xmlFilename;
	private OntologyData ontologyData;

	public XMLOntologyDataParser() {
		this.ontologyData = new OntologyData();

	}

	public XMLOntologyDataParser(String xmlFilename) {
		this();
		this.xmlFilename = xmlFilename;
	}

	public OntologyData getOntologyData() {
		return ontologyData;
	}

	public void setOntologyData(OntologyData ontologyData) {
		this.ontologyData = ontologyData;
	}

	public OntologyData parse() {
		OntologyData od = new OntologyData();
		try {
			// creates and returns new instance of SAX-implementation:
			SAXParserFactory factory = SAXParserFactory.newInstance();

			// create SAX-parser...
			SAXParser parser = factory.newSAXParser();
			// .. define our handler:
			SaxHandler handler = new SaxHandler();

			// and parse:
			parser.parse(xmlFilename, handler);
			Map<String, Set<String>> loMap = handler.getLoMap();
			Set<String> concepts = loMap.keySet();
			for (String concept : concepts) {
				int number = loMap.get(concept).size();
				this.ontologyData.addFrequency(concept, number);
			}

		} catch (Exception ex) {
			System.out
					.println("[ATENO]: Erro processando arquivo de frequncias. Verifique"
							+ "\nse o nome do arquivo est correto ou se o arquivo"
							+ "\nde correspondncias est bem formado.");
			ex.printStackTrace(System.out);
		}
		return od;
	}

	public String getXmlFilename() {
		return xmlFilename;
	}

	public void setXmlFilename(String xmlFilename) {
		this.xmlFilename = xmlFilename;
	}

	private static final class SaxHandler extends DefaultHandler {

		private Map<String, Set<String>> loMap = new HashMap<String, Set<String>>();

		public Map<String, Set<String>> getLoMap() {
			return loMap;
		}

		public void setLoMap(Map<String, Set<String>> loMap) {
			this.loMap = loMap;
		}

		@Override
		public void startElement(String uri, String localName, String qName,
				Attributes attrs) throws SAXException {

			if (qName.equals("LOCLASS")) {
				String concept = attrs.getValue("label");
				String localOntology = attrs.getValue("lo");
				Set<String> los = this.loMap.get(concept);
				if (los == null) {
					los = new HashSet<String>();
					los.add(localOntology);
					loMap.put(concept, los);
				} else {
					los.add(localOntology);
				}
			}
		}
	}

	public static void main(String[] args) {
		XMLOntologyDataParser xodp = new XMLOntologyDataParser(
				"etc/correspondences.xml");
		xodp.parse();
		System.out.println(xodp.getOntologyData());
	}
}
