package summarizer;

import java.util.HashSet;
import java.util.Set;

import junit.framework.TestCase;

public class FMeasureGraphCalculatorTest extends TestCase {

	Graph sample;
	OntologyData data;

	Node course;
	Node faculty;
	Node posdoc;
	Node lecturer;
	Node professor;
	Node graduate;
	Node student;

	Edge teacherOf;

	public FMeasureGraphCalculatorTest(String name) {
		super(name);
	}

	@Override
	protected void setUp() throws Exception {
		super.setUp();
		this.sample = new Graph();
		this.sample.setName("Sample Test Graph 1");
		this.data = new OntologyData();
		this.data.addFrequency("Course", 4);
		this.data.addFrequency("Faculty", 2);
		this.data.addFrequency("Posdoc", 2);
		this.data.addFrequency("Lecturer", 1);
		this.data.addFrequency("Professor", 2);
		this.data.addFrequency("Graduate", 3);
		this.data.addFrequency("Student", 2);

		this.course = new Node(1, "Course");
		this.faculty = new Node(2, "Faculty");
		this.posdoc = new Node(3, "Posdoc");
		this.lecturer = new Node(4, "Lecturer");
		this.professor = new Node(5, "Professor");
		this.graduate = new Node(6, "Graduate");
		this.student = new Node(7, "Student");

		teacherOf = new Edge(course, faculty, "teacherOf");
		Edge takes = new Edge(student, course, "takes");
		Edge isAdivisor = new Edge(graduate, professor, "isAdivisor");
		Edge learn = new Edge(graduate, lecturer, "learn");
		Edge is_a1 = new Edge(posdoc, faculty, "is-a");
		Edge is_a2 = new Edge(lecturer, faculty, "is-a");
		Edge is_a3 = new Edge(professor, faculty, "is-a");
		Edge is_a4 = new Edge(graduate, student, "is-a");

		this.sample.addNode(course);
		this.sample.addNode(faculty);
		this.sample.addNode(posdoc);
		this.sample.addNode(lecturer);
		this.sample.addNode(professor);
		this.sample.addNode(graduate);
		this.sample.addNode(student);

		this.sample.addEdge(teacherOf);
		this.sample.addEdge(takes);
		this.sample.addEdge(isAdivisor);
		this.sample.addEdge(learn);
		this.sample.addEdge(is_a1);
		this.sample.addEdge(is_a2);
		this.sample.addEdge(is_a3);
		this.sample.addEdge(is_a4);

	}

	@Override
	protected void tearDown() throws Exception {
		super.tearDown();
	}

	public void testGetNodeCentrality() {
		FMeasureGraphCalculator dgs = new FMeasureGraphCalculator();
		assertEquals(2, dgs.getNodeCentrality(sample, course));
		assertEquals(4, dgs.getNodeCentrality(sample, faculty));
		assertEquals(1, dgs.getNodeCentrality(sample, posdoc));
		assertEquals(2, dgs.getNodeCentrality(sample, lecturer));
		assertEquals(2, dgs.getNodeCentrality(sample, professor));
		assertEquals(3, dgs.getNodeCentrality(sample, graduate));
		assertEquals(2, dgs.getNodeCentrality(sample, student));
	}

	public void testGetNodeNormalizedCentrality() {
		FMeasureGraphCalculator dgs = new FMeasureGraphCalculator();
		assertEquals(2.0 / 6.0, dgs.getNodeNormalizedCentrality(sample, course));
		assertEquals(4.0 / 6.0, dgs
				.getNodeNormalizedCentrality(sample, faculty));
		assertEquals(1.0 / 6.0, dgs.getNodeNormalizedCentrality(sample, posdoc));
		assertEquals(2.0 / 6.0, dgs.getNodeNormalizedCentrality(sample,
				lecturer));
		assertEquals(2.0 / 6.0, dgs.getNodeNormalizedCentrality(sample,
				professor));
		assertEquals(3.0 / 6.0, dgs.getNodeNormalizedCentrality(sample,
				graduate));
		assertEquals(2.0 / 6.0, dgs
				.getNodeNormalizedCentrality(sample, student));
	}

	public void testGetNodeFrequency() {
		FMeasureGraphCalculator dgs = new FMeasureGraphCalculator();
		assertEquals(4, dgs.getNodeFrequency(sample, course, data));
		assertEquals(2, dgs.getNodeFrequency(sample, faculty, data));
		assertEquals(2, dgs.getNodeFrequency(sample, posdoc, data));
		assertEquals(1, dgs.getNodeFrequency(sample, lecturer, data));
		assertEquals(2, dgs.getNodeFrequency(sample, professor, data));
		assertEquals(3, dgs.getNodeFrequency(sample, graduate, data));
		assertEquals(2, dgs.getNodeFrequency(sample, student, data));
	}

	public void testGetNodeNormalizedFrequency() {
		FMeasureGraphCalculator dgs = new FMeasureGraphCalculator();
		assertEquals(4.0 / 4.0, dgs.getNodeNormalizedFrequency(sample, course,
				data));
		assertEquals(2.0 / 4.0, dgs.getNodeNormalizedFrequency(sample, faculty,
				data));
		assertEquals(2.0 / 4.0, dgs.getNodeNormalizedFrequency(sample, posdoc,
				data));
		assertEquals(1.0 / 4.0, dgs.getNodeNormalizedFrequency(sample,
				lecturer, data));
		assertEquals(2.0 / 4.0, dgs.getNodeNormalizedFrequency(sample,
				professor, data));
		assertEquals(3.0 / 4.0, dgs.getNodeNormalizedFrequency(sample,
				graduate, data));
		assertEquals(2.0 / 4.0, dgs.getNodeNormalizedFrequency(sample, student,
				data));
	}

	public void testGetAverageNodeRelevance() {
		FMeasureGraphCalculator dgs = new FMeasureGraphCalculator();
		assertEquals(0.47619047619047616, dgs.getAverageNodeRelevance(sample,
				data, 0.5, 0.5));
	}

	public void testGetRelevantNodes() {
		FMeasureGraphCalculator dgs = new FMeasureGraphCalculator();
		dgs.calculateNodesRelevancies(sample, data, 0.5, 0.5);
		assertEquals(3, sample.getRelevantNodes().size());
		assertEquals(course, sample.getRelevantNodes().get(0));
		assertEquals(graduate, sample.getRelevantNodes().get(1));
		assertEquals(faculty, sample.getRelevantNodes().get(2));
	}

	public void testGetNodeRelevance() {
		FMeasureGraphCalculator dgs = new FMeasureGraphCalculator();
		assertEquals((0.5 * (2.0 / 6.0) + 0.5 * (4.0 / 4.0)), dgs
				.getNodeRelevance(sample, course, data, 0.5, 0.5));
		assertEquals((0.5 * (4.0 / 6.0) + 0.5 * (2.0 / 4.0)), dgs
				.getNodeRelevance(sample, faculty, data, 0.5, 0.5));
		assertEquals((0.5 * (2.0 / 6.0) + 0.5 * (2.0 / 4.0)), dgs
				.getNodeRelevance(sample, student, data, 0.5, 0.5));
		assertEquals((0.5 * (1.0 / 6.0) + 0.5 * (2.0 / 4.0)), dgs
				.getNodeRelevance(sample, posdoc, data, 0.5, 0.5));
		assertEquals((0.5 * (2.0 / 6.0) + 0.5 * (1.0 / 4.0)), dgs
				.getNodeRelevance(sample, lecturer, data, 0.5, 0.5));
		assertEquals((0.5 * (2.0 / 6.0) + 0.5 * (2.0 / 4.0)), dgs
				.getNodeRelevance(sample, professor, data, 0.5, 0.5));
		assertEquals((0.5 * (3.0 / 6.0) + 0.5 * (3.0 / 4.0)), dgs
				.getNodeRelevance(sample, graduate, data, 0.5, 0.5));
	}

	public void testGetJoinUnjoinNodesGraph1() {
		FMeasureGraphCalculator dgs = new FMeasureGraphCalculator();
		Graph jointed = dgs.getJointNodesGraph(sample, teacherOf);
		assertEquals(6, jointed.getNodes().size());
		assertEquals(7, jointed.getEdges().size());
		assertTrue(!jointed.getNodes().contains(course));
		assertTrue(!jointed.getNodes().contains(faculty));
		assertTrue(!jointed.getEdges().contains(teacherOf));

		Graph unjoined = dgs.unjoinGraph(jointed);
		assertEquals(sample, unjoined);

		Graph subgraph = jointed.getSubgraph();
		assertEquals(2, subgraph.getNodes().size());
		assertEquals(1, subgraph.getEdges().size());
		assertTrue(subgraph.getNodes().contains(course));
		assertTrue(subgraph.getNodes().contains(faculty));
		assertTrue(subgraph.getEdges().contains(teacherOf));
	}

	public void testGetJoinUnjoinNodesGraph2() {
		FMeasureGraphCalculator dgs = new FMeasureGraphCalculator();
		Graph jointed = dgs.getJointNodesGraph(sample, teacherOf);
		Edge autoEdgeStudent1 = new Edge(student, student, "Autoedge Student 1");
		sample.addEdge(autoEdgeStudent1);
		Edge autoEdgeStudent2 = new Edge(student, student, "Autoedge Student 2");
		sample.addEdge(autoEdgeStudent2);
		Edge autoEdgeFaculty1 = new Edge(faculty, faculty, "Autoedge Faculty 1");
		sample.addEdge(autoEdgeFaculty1);
		Edge autoEdgeFaculty2 = new Edge(faculty, faculty, "Autoedge Faculty 2");
		sample.addEdge(autoEdgeFaculty2);
		Edge autoEdgeCourse = new Edge(course, course, "Autoedge Course");
		sample.addEdge(autoEdgeCourse);
		jointed = dgs.getJointNodesGraph(sample, teacherOf);
		assertEquals(6, jointed.getNodes().size());
		assertEquals(8, jointed.getEdges().size());
		assertTrue(!jointed.getNodes().contains(course));
		assertTrue(!jointed.getNodes().contains(faculty));
		assertTrue(!jointed.getEdges().contains(teacherOf));
		assertTrue(!jointed.getEdges().contains(autoEdgeFaculty1));
		assertTrue(!jointed.getEdges().contains(autoEdgeFaculty2));
		assertTrue(!jointed.getEdges().contains(autoEdgeCourse));
		assertTrue(jointed.getEdges().contains(autoEdgeStudent1));
		assertTrue(jointed.getEdges().contains(autoEdgeStudent2));

		Graph unjoined = dgs.unjoinGraph(jointed);
		assertEquals(sample, unjoined);

		Graph subgraph = jointed.getSubgraph();
		assertEquals(2, subgraph.getNodes().size());
		assertEquals(3, subgraph.getEdges().size());
		assertTrue(subgraph.getNodes().contains(course));
		assertTrue(subgraph.getNodes().contains(faculty));
		assertTrue(subgraph.getEdges().contains(teacherOf));
		assertTrue(subgraph.getEdges().contains(autoEdgeFaculty1));
		assertTrue(subgraph.getEdges().contains(autoEdgeFaculty2));
		assertTrue(subgraph.getEdges().contains(autoEdgeCourse));
	}

	public void testGetEdges() {
		Graph gr = new Graph();
		gr.setName("Grafo de Teste");
		Node n1 = new Node(1, "no1");
		Node n2 = new Node(2, "no2");
		Node n3 = new Node(3, "no3");
		Node n4 = new Node(4, "no4");
		Node n5 = new Node(5, "no5");

		Edge e1 = new Edge(n1, n2);
		e1.addLabel("1para2");
		Edge e2 = new Edge(n1, n3);
		e1.addLabel("1para3");
		Edge e3 = new Edge(n2, n4);
		e1.addLabel("1para3");
		Edge e4 = new Edge(n5, n1);
		e1.addLabel("1para3");

		gr.addNode(n1);
		gr.addNode(n2);
		gr.addNode(n3);
		gr.addNode(n4);
		gr.addNode(n5);

		gr.addEdge(e1);
		gr.addEdge(e2);
		gr.addEdge(e3);
		gr.addEdge(e4);
		FMeasureGraphCalculator calc = new FMeasureGraphCalculator();
		Set<Edge> edges = calc.getGraphEdgesByNode(gr, n1);
		assertEquals(3, edges.size());
		assertTrue(edges.contains(e1));
		assertTrue(edges.contains(e2));
		assertTrue(edges.contains(e4));
	}

	public void testGetAllPaths1() {
		Graph gr = new Graph();
		gr.setName("Grafo de Teste");
		Node a = new Node(1, "A");
		Node b = new Node(2, "B");
		Node c = new Node(3, "C");
		Node d = new Node(4, "D");
		Node e = new Node(5, "E");
		Node f = new Node(6, "F");
		Node g = new Node(7, "G");
		Node h = new Node(8, "H");
		Node i = new Node(9, "I");
		Node j = new Node(10, "J");
		Node n = new Node(11, "N");
		Node k = new Node(12, "K");
		Node v = new Node(13, "V");
		Node m = new Node(14, "M");
		Node l = new Node(15, "L");
		Node o = new Node(16, "O");
		Node p = new Node(17, "P");
		Node q = new Node(18, "Q");
		Node r = new Node(19, "R");
		Node s = new Node(20, "S");
		Node u = new Node(21, "U");
		Node z = new Node(22, "Z");
		gr.addNode(a);
		gr.addNode(b);
		gr.addNode(c);
		gr.addNode(d);
		gr.addNode(e);
		gr.addNode(f);
		gr.addNode(g);
		gr.addNode(h);
		gr.addNode(i);
		gr.addNode(j);
		gr.addNode(k);
		gr.addNode(l);
		gr.addNode(m);
		gr.addNode(n);
		gr.addNode(o);
		gr.addNode(p);
		gr.addNode(q);
		gr.addNode(r);
		gr.addNode(s);
		gr.addNode(u);
		gr.addNode(v);
		gr.addNode(z);

		Set<Edge> edges = new HashSet<Edge>();
		edges.add(new Edge(a, a));
		edges.add(new Edge(a, b));
		edges.add(new Edge(b, f));
		edges.add(new Edge(f, j));
		edges.add(new Edge(j, m));

		edges.add(new Edge(a, c));
		edges.add(new Edge(g, c));
		edges.add(new Edge(n, g));
		edges.add(new Edge(m, n));

		edges.add(new Edge(a, d));
		edges.add(new Edge(h, d));
		edges.add(new Edge(n, h));

		edges.add(new Edge(c, c));
		edges.add(new Edge(c, d));
		edges.add(new Edge(g, h));
		edges.add(new Edge(g, z));

		edges.add(new Edge(a, e));
		edges.add(new Edge(h, k));
		edges.add(new Edge(k, l));
		edges.add(new Edge(l, o));
		edges.add(new Edge(o, q));
		edges.add(new Edge(o, p));
		edges.add(new Edge(o, r));
		edges.add(new Edge(q, s));
		edges.add(new Edge(r, u));
		edges.add(new Edge(e, i));
		edges.add(new Edge(i, v));

		gr.setEdges(edges);

		Graph subg1 = new Graph();
		subg1.setName("Subgrafo de A para N pelo caminho 1");
		subg1.addNode(a);
		subg1.addNode(b);
		subg1.addNode(f);
		subg1.addNode(j);
		subg1.addNode(m);
		Set<Edge> edges1 = new HashSet<Edge>();
		edges1.add(new Edge(a, a));
		edges1.add(new Edge(a, b));
		edges1.add(new Edge(b, f));
		edges1.add(new Edge(f, j));
		edges1.add(new Edge(j, m));
		subg1.setEdges(edges1);

		Graph subg2 = new Graph();
		subg2.setName("Subgrafo de A para N pelo caminho 2");
		subg2.addNode(a);
		subg2.addNode(c);
		subg2.addNode(g);
		subg2.addNode(n);
		subg2.addNode(m);
		Set<Edge> edges21 = new HashSet<Edge>();
		edges21.add(new Edge(a, a));
		edges21.add(new Edge(c, c));
		edges21.add(new Edge(a, c));
		edges21.add(new Edge(g, c));
		edges21.add(new Edge(n, g));
		edges21.add(new Edge(m, n));
		subg2.setEdges(edges21);

		Graph subg3 = new Graph();
		subg3.setName("Subgrafo de A para N pelo caminho 3");
		subg3.addNode(a);
		subg3.addNode(d);
		subg3.addNode(h);
		subg3.addNode(n);
		subg3.addNode(m);
		Set<Edge> edges31 = new HashSet<Edge>();
		edges31.add(new Edge(a, d));
		edges31.add(new Edge(a, a));
		edges31.add(new Edge(h, d));
		edges31.add(new Edge(n, h));
		edges31.add(new Edge(m, n));
		subg3.setEdges(edges31);

		Graph subg4 = new Graph();
		subg4.setName("Subgrafo de A para N pelo caminho 4");
		subg4.addNode(a);
		subg4.addNode(c);
		subg4.addNode(d);
		subg4.addNode(h);
		subg4.addNode(n);
		subg4.addNode(m);
		Set<Edge> edges41 = new HashSet<Edge>();
		edges41.add(new Edge(a, a));
		edges41.add(new Edge(c, c));
		edges41.add(new Edge(a, c));
		edges41.add(new Edge(c, d));
		edges41.add(new Edge(h, d));
		edges41.add(new Edge(n, h));
		edges41.add(new Edge(m, n));
		subg4.setEdges(edges41);

		Graph subg5 = new Graph();
		subg5.setName("Subgrafo de A para N pelo caminho 5");
		subg5.addNode(a);
		subg5.addNode(c);
		subg5.addNode(d);
		subg5.addNode(g);
		subg5.addNode(n);
		subg5.addNode(m);
		Set<Edge> edges51 = new HashSet<Edge>();
		edges51.add(new Edge(a, a));
		edges51.add(new Edge(c, c));
		edges51.add(new Edge(a, d));
		edges51.add(new Edge(c, d));
		edges51.add(new Edge(g, c));
		edges51.add(new Edge(n, g));
		edges51.add(new Edge(m, n));
		subg5.setEdges(edges51);

		FMeasureGraphCalculator calc = new FMeasureGraphCalculator();
		calc.setSummarySizeReference(0);
		calc.setSummarySizeDelta(100);
		Set<Graph> subgraphs = calc.getAllPaths(gr, a, m);
		assertEquals(9, subgraphs.size());
		boolean ok1 = false;
		boolean ok2 = false;
		boolean ok3 = false;
		boolean ok4 = false;
		boolean ok5 = false;
		System.out.println(subg1.hashCode());
		for (Graph graph : subgraphs) {
			System.out.println(graph.hashCode());
			if (graph.equals(subg1)) {
				ok1 = true;
			}
			if (graph.equals(subg2)) {
				ok2 = true;
			}
			if (graph.equals(subg3)) {
				ok3 = true;
			}
			if (graph.equals(subg4)) {
				ok4 = true;
			}
			if (graph.equals(subg5)) {
				ok5 = true;
			}
		}
		assertTrue(ok1);
		assertTrue(ok2);
		assertTrue(ok3);
		assertTrue(ok4);
		assertTrue(ok5);

	}

	public void testGetAllPaths2() {
		Graph gr = new Graph();
		gr.setName("Grafo de Teste");
		Node a = new Node(1, "A");
		Node b = new Node(2, "B");
		Node c = new Node(3, "C");
		Node d = new Node(4, "D");
		Node e = new Node(5, "E");
		Node f = new Node(6, "F");
		Node g = new Node(7, "G");
		Node h = new Node(8, "H");
		Node i = new Node(9, "I");
		Node j = new Node(10, "J");
		Node n = new Node(11, "N");
		Node k = new Node(12, "K");
		Node v = new Node(13, "V");
		Node m = new Node(14, "M");
		Node l = new Node(15, "L");
		Node o = new Node(16, "O");
		Node p = new Node(17, "P");
		Node q = new Node(18, "Q");
		Node r = new Node(19, "R");
		Node s = new Node(20, "S");
		Node u = new Node(21, "U");
		Node z = new Node(22, "Z");
		gr.addNode(a);
		gr.addNode(b);
		gr.addNode(c);
		gr.addNode(d);
		gr.addNode(e);
		gr.addNode(f);
		gr.addNode(g);
		gr.addNode(h);
		gr.addNode(i);
		gr.addNode(j);
		gr.addNode(k);
		gr.addNode(l);
		gr.addNode(m);
		gr.addNode(n);
		gr.addNode(o);
		gr.addNode(p);
		gr.addNode(q);
		gr.addNode(r);
		gr.addNode(s);
		gr.addNode(u);
		gr.addNode(v);
		gr.addNode(z);

		Set<Edge> edges = new HashSet<Edge>();
		edges.add(new Edge(a, b));
		edges.add(new Edge(b, f));
		edges.add(new Edge(f, j));
		edges.add(new Edge(j, m));

		edges.add(new Edge(a, c));
		edges.add(new Edge(g, c));
		edges.add(new Edge(n, g));
		edges.add(new Edge(m, n));

		edges.add(new Edge(a, d));
		edges.add(new Edge(h, d));
		edges.add(new Edge(n, h));

		edges.add(new Edge(c, d));
		edges.add(new Edge(g, h));
		edges.add(new Edge(g, z));

		edges.add(new Edge(a, e));
		edges.add(new Edge(h, k));
		edges.add(new Edge(k, l));
		edges.add(new Edge(l, o));
		edges.add(new Edge(o, q));
		edges.add(new Edge(o, p));
		edges.add(new Edge(o, r));
		edges.add(new Edge(q, s));
		edges.add(new Edge(r, u));
		edges.add(new Edge(e, i));
		edges.add(new Edge(i, v));

		gr.setEdges(edges);

		Graph subg1 = new Graph();
		subg1.setName("Subgrafo de A para N pelo caminho 1");
		subg1.addNode(a);
		subg1.addNode(b);
		subg1.addNode(f);
		subg1.addNode(j);
		subg1.addNode(m);
		subg1.addNode(n);
		Set<Edge> edges1 = new HashSet<Edge>();
		edges1.add(new Edge(a, b));
		edges1.add(new Edge(b, f));
		edges1.add(new Edge(f, j));
		edges1.add(new Edge(j, m));
		edges1.add(new Edge(m, n));
		subg1.setEdges(edges1);

		Graph subg2 = new Graph();
		subg2.setName("Subgrafo de A para N pelo caminho 2");
		subg2.addNode(a);
		subg2.addNode(c);
		subg2.addNode(g);
		subg2.addNode(n);
		Set<Edge> edges21 = new HashSet<Edge>();
		edges21.add(new Edge(a, c));
		edges21.add(new Edge(g, c));
		edges21.add(new Edge(n, g));
		subg2.setEdges(edges21);

		Graph subg3 = new Graph();
		subg3.setName("Subgrafo de A para N pelo caminho 3");
		subg3.addNode(a);
		subg3.addNode(d);
		subg3.addNode(h);
		subg3.addNode(n);
		Set<Edge> edges31 = new HashSet<Edge>();
		edges31.add(new Edge(a, d));
		edges31.add(new Edge(h, d));
		edges31.add(new Edge(n, h));
		subg3.setEdges(edges31);

		Graph subg4 = new Graph();
		subg4.setName("Subgrafo de A para N pelo caminho 4");
		subg4.addNode(a);
		subg4.addNode(c);
		subg4.addNode(d);
		subg4.addNode(h);
		subg4.addNode(n);
		Set<Edge> edges41 = new HashSet<Edge>();
		edges41.add(new Edge(a, c));
		edges41.add(new Edge(c, d));
		edges41.add(new Edge(h, d));
		edges41.add(new Edge(n, h));
		subg4.setEdges(edges41);

		Graph subg5 = new Graph();
		subg5.setName("Subgrafo de A para N pelo caminho 5");
		subg5.addNode(a);
		subg5.addNode(c);
		subg5.addNode(d);
		subg5.addNode(g);
		subg5.addNode(n);
		Set<Edge> edges51 = new HashSet<Edge>();
		edges51.add(new Edge(a, d));
		edges51.add(new Edge(c, d));
		edges51.add(new Edge(g, c));
		edges51.add(new Edge(n, g));
		subg5.setEdges(edges51);

		FMeasureGraphCalculator calc = new FMeasureGraphCalculator();
		calc.setSummarySizeReference(0);
		calc.setSummarySizeDelta(100);
		Set<Graph> subgraphs = calc.getAllPaths(gr, a, n);
		assertEquals(9, subgraphs.size());
		assertTrue(subgraphs.contains(subg1));
		assertTrue(subgraphs.contains(subg2));
		assertTrue(subgraphs.contains(subg3));
		assertTrue(subgraphs.contains(subg4));
		assertTrue(subgraphs.contains(subg5));

		subgraphs = calc.getAllPaths(gr, a, i);
		assertEquals(1, subgraphs.size());
		subgraphs = calc.getAllPaths(gr, a, v);
		assertEquals(1, subgraphs.size());

		subgraphs = calc.getAllPaths(gr, a, o);
		assertEquals(12, subgraphs.size());
		subgraphs = calc.getAllPaths(gr, a, s);
		assertEquals(12, subgraphs.size());
		subgraphs = calc.getAllPaths(gr, a, u);
		assertEquals(12, subgraphs.size());

	}

	public void testGetFmeasure() {
		Graph gr = new Graph();
		gr.setName("Grafo de Teste");
		Node a = new Node(1, "A");
		Node b = new Node(2, "B");
		Node c = new Node(3, "C");
		Node d = new Node(4, "D");
		Node e = new Node(5, "E");
		Node f = new Node(6, "F");
		Node g = new Node(7, "G");
		Node h = new Node(8, "H");
		Node i = new Node(9, "I");
		Node j = new Node(10, "J");
		Node n = new Node(11, "N");
		Node k = new Node(12, "K");
		Node v = new Node(13, "V");
		Node m = new Node(14, "M");
		Node l = new Node(15, "L");
		Node o = new Node(16, "O");
		Node p = new Node(17, "P");
		Node q = new Node(18, "Q");
		Node r = new Node(19, "R");
		Node s = new Node(20, "S");
		Node u = new Node(21, "U");

		Node m1 = new Node(22, "M1");
		Node m2 = new Node(23, "M2");
		Node m3 = new Node(24, "M3");

		Node n1 = new Node(25, "N1");
		Node n2 = new Node(26, "N2");
		Node n3 = new Node(27, "N3");

		Node s1 = new Node(28, "S1");
		Node s2 = new Node(29, "S2");
		Node s3 = new Node(30, "S3");

		Node u1 = new Node(31, "U1");
		Node u2 = new Node(32, "U2");
		Node u3 = new Node(33, "U3");

		Node v1 = new Node(34, "V1");
		Node v2 = new Node(35, "V2");
		Node v3 = new Node(36, "V3");

		Node i1 = new Node(37, "I1");
		Node i2 = new Node(38, "I2");

		gr.addNode(a);
		gr.addNode(b);
		gr.addNode(c);
		gr.addNode(d);
		gr.addNode(e);
		gr.addNode(f);
		gr.addNode(g);
		gr.addNode(h);
		gr.addNode(i);
		gr.addNode(j);
		gr.addNode(k);
		gr.addNode(l);
		gr.addNode(m);
		gr.addNode(n);
		gr.addNode(o);
		gr.addNode(p);
		gr.addNode(q);
		gr.addNode(r);
		gr.addNode(s);
		gr.addNode(u);
		gr.addNode(v);

		gr.addNode(m1);
		gr.addNode(m2);
		gr.addNode(m3);

		gr.addNode(n1);
		gr.addNode(n2);
		gr.addNode(n3);

		gr.addNode(s1);
		gr.addNode(s2);
		gr.addNode(s3);

		gr.addNode(u1);
		gr.addNode(u2);
		gr.addNode(u3);

		gr.addNode(v1);
		gr.addNode(v2);
		gr.addNode(v3);

		gr.addNode(i1);
		gr.addNode(i2);

		Set<Edge> edges = new HashSet<Edge>();
		edges.add(new Edge(a, b));
		edges.add(new Edge(b, f));
		edges.add(new Edge(f, j));
		edges.add(new Edge(j, m));

		edges.add(new Edge(a, c));
		edges.add(new Edge(g, c));
		edges.add(new Edge(n, g));
		edges.add(new Edge(m, n));

		edges.add(new Edge(a, d));
		edges.add(new Edge(h, d));
		edges.add(new Edge(n, h));

		edges.add(new Edge(e, a));
		edges.add(new Edge(h, k));
		edges.add(new Edge(k, l));
		edges.add(new Edge(l, o));
		edges.add(new Edge(o, q));
		edges.add(new Edge(o, p));
		edges.add(new Edge(o, r));
		edges.add(new Edge(q, s));
		edges.add(new Edge(r, u));
		edges.add(new Edge(i, e));
		edges.add(new Edge(v, i));

		edges.add(new Edge(m1, m));
		edges.add(new Edge(m2, m));
		edges.add(new Edge(m3, m));

		edges.add(new Edge(n1, n));
		edges.add(new Edge(n2, n));
		edges.add(new Edge(n3, n));

		edges.add(new Edge(s1, s));
		edges.add(new Edge(s2, s));
		edges.add(new Edge(s3, s));

		edges.add(new Edge(u1, u));
		edges.add(new Edge(u2, u));
		edges.add(new Edge(u3, u));

		edges.add(new Edge(v1, v));
		edges.add(new Edge(v2, v));
		edges.add(new Edge(v3, v));

		edges.add(new Edge(i1, i));
		edges.add(new Edge(i2, i));

		gr.setEdges(edges);

		OntologyData od = new OntologyData();
		od.addFrequency("A", 1);
		od.addFrequency("B", 1);
		od.addFrequency("C", 1);
		od.addFrequency("D", 1);
		od.addFrequency("E", 1);
		od.addFrequency("F", 1);
		od.addFrequency("G", 1);
		od.addFrequency("H", 1);
		od.addFrequency("I", 1);
		od.addFrequency("J", 1);
		od.addFrequency("N", 1);
		od.addFrequency("K", 1);
		od.addFrequency("V", 1);
		od.addFrequency("M", 1);
		od.addFrequency("L", 1);
		od.addFrequency("O", 1);
		od.addFrequency("P", 1);
		od.addFrequency("Q", 1);
		od.addFrequency("R", 1);
		od.addFrequency("S", 1);
		od.addFrequency("U", 1);
		od.addFrequency("M1", 1);
		od.addFrequency("M2", 1);
		od.addFrequency("M3", 1);
		od.addFrequency("N1", 1);
		od.addFrequency("N2", 1);
		od.addFrequency("N3", 1);
		od.addFrequency("S1", 1);
		od.addFrequency("S2", 1);
		od.addFrequency("S3", 1);
		od.addFrequency("U1", 1);
		od.addFrequency("U2", 1);
		od.addFrequency("U3", 1);
		od.addFrequency("V1", 1);
		od.addFrequency("V2", 1);
		od.addFrequency("V3", 1);
		od.addFrequency("I1", 1);
		od.addFrequency("I2", 1);

		FMeasureGraphCalculator fCalc = new FMeasureGraphCalculator();
		fCalc.calculateNodesRelevancies(gr, od, 0.5, 0.5, 8);
		assertEquals(8, gr.getRelevantNodes().size());
		assertTrue(gr.getRelevantNodes().contains(n));
		assertTrue(gr.getRelevantNodes().contains(m));
		assertTrue(gr.getRelevantNodes().contains(a));
		assertTrue(gr.getRelevantNodes().contains(i));
		assertTrue(gr.getRelevantNodes().contains(o));
		assertTrue(gr.getRelevantNodes().contains(v));
		assertTrue(gr.getRelevantNodes().contains(s));
		assertTrue(gr.getRelevantNodes().contains(u));

		fCalc.setOriginalGraph(gr);
		fCalc.setOntologyData(null);
		fCalc.setRelevantNodesLimit(8);
		fCalc.setSummarySizeDelta(0);
		fCalc.setSummarySizeDelta(8);
		Graph summary = fCalc.getSummary();
		System.out.println(summary);
		System.out.println("Summary Size: " + summary.getSize(true));
		System.out.println("Summary F-Measure: " + summary.getFMeasure());
		System.out.println("Summary Relevance: " + summary.getRelevance());
		assertEquals(8, summary.getSize(true));

	}
}
