package summarizer;

import java.util.Set;

import junit.framework.TestCase;
import summarizer.Edge;
import summarizer.Graph;
import summarizer.Node;

public class GraphTest extends TestCase {

	private Graph g;

	public GraphTest(String name) {
		super(name);
	}

	@Override
	protected void setUp() throws Exception {
		super.setUp();
		g = new Graph();
		g.setName("Grafo de Teste");
		Node n1 = new Node(1, "no1");
		Node n2 = new Node(2, "no2");
		Node n3 = new Node(3, "no3");
		Node n4 = new Node(4, "no4");

		Edge e1 = new Edge(n1, n1);
		e1.addLabel("auto-rel");
		Edge e2 = new Edge(n1, n2);
		e2.addLabel("ida12");
		Edge e3 = new Edge(n1, n3);
		e3.addLabel("ida13");
		Edge e4 = new Edge(n2, n4);
		e4.addLabel("ida24");
		Edge e5 = new Edge(n4, n3);
		e5.addLabel("ida43.1");
		Edge e6 = new Edge(n4, n3);
		e6.addLabel("ida43.2");
		g.addNode(n1);
		g.addNode(n2);
		g.addNode(n3);
		g.addNode(n4);

		g.addEdge(e1);
		g.addEdge(e2);
		g.addEdge(e3);
		g.addEdge(e4);
		g.addEdge(e5);
		g.addEdge(e6);
	}

	@Override
	protected void tearDown() throws Exception {
		super.tearDown();
	}

	public void testAddEdge() {
		Graph gr = new Graph();
		gr.setName("Grafo de Teste");
		Node n1 = new Node(1, "no1");
		Node n2 = new Node(2, "no2");
		Edge e1 = new Edge(n1, n2);
		e1.addLabel("ida12.1");
		Edge e2 = new Edge(n1, n2);
		e2.addLabel("ida12.2");
		gr.addNode(n1);
		gr.addNode(n2);
		gr.addEdge(e1);
		gr.addEdge(e2);
		assertEquals(1, gr.getEdges().size());
		Edge e = null;
		for (Edge edge : gr.getEdges()) {
			e = edge;
		}
		assertEquals("ida12.2, ida12.1", e.getLabel());
	}

	public void testAppendLabelToNode() {
		Graph gr = new Graph();
		gr.setName("Grafo de Teste");
		Node n1 = new Node(1, "no1");
		Node n2 = new Node(2, "no2");

		Edge e0 = new Edge(n1, n1);
		e0.addLabel("1auto-rel1");

		Edge e1 = new Edge(n1, n1);
		e1.addLabel("1auto-rel0");

		Edge e2 = new Edge(n1, n2);
		e2.addLabel("1para2");

		gr.addNode(n1);
		gr.addNode(n2);

		gr.addEdge(e0);
		gr.addEdge(e1);
		gr.addEdge(e2);
		assertEquals(2, gr.getEdges().size());
		gr.appendAutoEdgeToLabelNode(1, "1auto-rel0");

		assertEquals(1, gr.getEdges().size());
		assertEquals("no1 (1auto-rel0)", gr.getNodeByID(1).getLabel());
		assertEquals("no1 (1auto-rel0)", gr.getEdgeByNodes(n1, n2).getSource()
				.getLabel());
		gr.appendAutoEdgeToLabelNode(1, "1auto-rel1");
		assertEquals("no1 (1auto-rel0) (1auto-rel1)", gr.getNodeByID(1)
				.getLabel());
		assertEquals("no1 (1auto-rel0) (1auto-rel1)", gr.getEdgeByNodes(n1, n2)
				.getSource().getLabel());
	}

	public void testGetNormalizedGraph() {
		Graph gr = new Graph();
		gr.setName("Grafo de Teste");
		Node n1 = new Node(1, "no1");
		Node n2 = new Node(2, "no2");

		Edge e0 = new Edge(n1, n1);
		e0.addLabel("1auto-rel1");

		Edge e1 = new Edge(n1, n1);
		e1.addLabel("1auto-rel0");

		Edge e2 = new Edge(n1, n2);
		e2.addLabel("1para2.1");
		Edge e3 = new Edge(n1, n2);
		e3.addLabel("1para2.2");

		gr.addNode(n1);
		gr.addNode(n2);

		gr.addEdge(e0);
		gr.addEdge(e1);
		gr.addEdge(e2);
		gr.addEdge(e3);

		Graph gn = gr.getNormalizedGraph(false);
		assertEquals(2, gr.getEdges().size());
		assertEquals(1, gn.getEdges().size());
		assertEquals("no1 (1auto-rel0, 1auto-rel1)", gn.getNodeByID(1)
				.getLabel());
		assertEquals("1para2.2, 1para2.1", gn.getEdgeByNodes(n1, n2).getLabel());
	}

	public void testGetEdges() {
		Graph gr = new Graph();
		gr.setName("Grafo de Teste");
		Node n1 = new Node(1, "no1");
		Node n2 = new Node(2, "no2");
		Node n3 = new Node(3, "no3");
		Node n4 = new Node(4, "no4");
		Node n5 = new Node(5, "no5");

		Edge e1 = new Edge(n1, n2);
		e1.addLabel("1para2");
		Edge e2 = new Edge(n1, n3);
		e1.addLabel("1para3");
		Edge e3 = new Edge(n2, n4);
		e1.addLabel("1para3");
		Edge e4 = new Edge(n5, n1);
		e1.addLabel("1para3");

		gr.addNode(n1);
		gr.addNode(n2);
		gr.addNode(n3);
		gr.addNode(n4);
		gr.addNode(n5);

		gr.addEdge(e1);
		gr.addEdge(e2);
		gr.addEdge(e3);
		gr.addEdge(e4);
		Set<Edge> edges = gr.getEdgesByNode(n1);
		assertEquals(3, edges.size());
		assertTrue(edges.contains(e1));
		assertTrue(edges.contains(e2));
		assertTrue(edges.contains(e4));
	}

}
